---
order: 10
---
# Use plain English

<!-- SPDX-License-Identifier: CC0-1.0 -->
<!-- SPDX-FileCopyrightText: 2019-2023 The Foundation for Public Code <info@publiccode.net>, https://standard.publiccode.net/AUTHORS -->

## Requirements

* All [codebase](../glossary.md#codebase) documentation MUST be in English.
* All [code](../glossary.md#code) MUST be in English, except where [policy](../glossary.md#policy) is machine interpreted as code.
* All bundled policy not available in English MUST have an accompanying summary in English.
* Any translation MUST be up to date with the English version and vice versa.
* There SHOULD be no acronyms, abbreviations, puns or legal/non-English/domain specific terms in the codebase without an explanation preceding it or a link to an explanation.
* Documentation SHOULD aim for a lower secondary education reading level, as recommended by the [Web Content Accessibility Guidelines 2](https://www.w3.org/WAI/WCAG21/quickref/?showtechniques=315#readable).
* Providing a translation of any code, documentation or tests is OPTIONAL.

## Why this is important

* Makes the codebase and what it does understandable for a wider variety of stakeholders in multiple contexts.
* Helps with the discoverability of the codebase.
* Can help you meet the [European Union accessibility directive](https://ec.europa.eu/digital-single-market/en/web-accessibility), which requires most public sector information to be accessible.
* Language that is easy to understand lowers the cost of creating and maintaining translations.

## What this does not do

* Make explanations of the codebase's functionality understandable.
* Make your organization's jargon understandable without an explanation.

## How to test

* Confirm that codebase documentation is available in English.
* Confirm that source code is in English, or confirm any non-English is policy or terms with preceding explanations.
* Confirm any non-English policy has an accompanying summary in English.
* Confirm that translations and the English version have the same content.
* Check that no unexplained acronyms, abbreviations, puns or legal/non-English/domain specific terms are in the documentation.
* Check the spelling, grammar and readability of the documentation.

## Policy makers: what you need to do

* Frequently test with other managers, developers and designers in the process if they understand what you are delivering and how you document it.

## Managers: what you need to do

* Try to limit the use of acronyms, abbreviations, puns or legal/non-English/domain specific terms in internal communications in and between teams and stakeholders. Add any such terms to a glossary and link to it from the places they are being used.
* Be critical of documentation and descriptions in proposals and changes. If you don't understand something, others will probably also struggle with it.

## Developers and designers: what you need to do

* Frequently test with policy makers and managers if they understand what you are delivering and how you document it.
* Ask someone outside of your context if they understand the content (for example, a developer working on a different codebase).

## Further reading

* Text of the [Web Content Accessibilty Guidelines 2.1, Guideline 3.1 Readable](https://www.w3.org/TR/WCAG21/#readable) by W3C, make text content readable and understandable.
* [Upgoer 5 text editor](https://splasho.com/upgoer5/) by Theo Sanderson, only allows 1000 most common English words.
* [Definition of plain language](https://www.plainlanguage.gov/about/definitions/) by United States General Services Administration.
